@@ -15,14 +15,16 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <stdio.h>
-
 #include "fs_hfs.h"
 #include "partimage.h"
 #include "imagefile.h"
 #include "misc.h"
 #include "gui_text.h"
 
+#include <stdio.h>
+#define __STDC_FORMAT_MACROS
+#include <inttypes.h>
+
 // =======================================================
 CHfsPart::CHfsPart(char *szDevice, FILE *fDeviceFile, QWORD qwPartSize): CFSBase(szDevice, fDeviceFile, qwPartSize)
 {
@@ -57,14 +59,14 @@ void CHfsPart::readSuperBlock()
   nRes = readData(&sb, 1024, sizeof(sb));
   if (nRes == -1)
     {
-      localDebug("ERROR 1\n");
+      showDebug(10, "ERROR 1\n");
       g_interface -> ErrorReadingSuperblock(errno);
       THROW(ERR_READING, (DWORD)0, errno);
     }
 
   if (Be16ToCpu(GET_WORD(&sb.drSigWord)) != HFS_SUPER_MAGIC)
     {
-      localDebug("ERROR 2\n");
+      showDebug(10, "ERROR 2\n");
       g_interface -> ErrorReadingSuperblock(errno);
       THROW(ERR_READING, (DWORD)0, errno);
     }
@@ -88,36 +90,36 @@ void CHfsPart::readSuperBlock()
   nRes = readData(&sb2, (m_info.qwFirstAllocBlock+qwBlocksInRegularAlloc)*512LL, sizeof(sb2));
   if (nRes == -1)
     {
-      localDebug("ERROR 3\n");
+      showDebug(10, "ERROR 3\n");
       g_interface -> ErrorReadingSuperblock(errno);
       THROW(ERR_READING, (DWORD)0, errno);
     }
 
   if (Be16ToCpu(GET_WORD(&sb.drSigWord)) != HFS_SUPER_MAGIC)
     {
-      localDebug("ERROR 4\n");
+      showDebug(10, "ERROR 4\n");
       g_interface -> ErrorReadingSuperblock(errno);
       THROW(ERR_READING, (DWORD)0, errno);
     }
 
   // show infos
-  localDebug("m_info.qwAllocCount=%llu\n", m_info.qwAllocCount);
-  localDebug("m_info.dwAllocSize=%lu=%lu sectors\n", m_info.dwAllocSize, m_info.dwBlocksPerAlloc);
-  localDebug("m_info.qwBitmapSectLocation=%llu\n", m_info.qwBitmapSectLocation);
-  localDebug("m_info.qwFirstAllocBlock=%llu\n", m_info.qwFirstAllocBlock);
-  localDebug("m_info.qwFreeAllocs=%llu\n", m_info.qwFreeAllocs);
+  showDebug(10, "m_info.qwAllocCount=%llu\n", m_info.qwAllocCount);
+  showDebug(10, "m_info.dwAllocSize=%lu=%lu sectors\n", m_info.dwAllocSize, m_info.dwBlocksPerAlloc);
+  showDebug(10, "m_info.qwBitmapSectLocation=%llu\n", m_info.qwBitmapSectLocation);
+  showDebug(10, "m_info.qwFirstAllocBlock=%llu\n", m_info.qwFirstAllocBlock);
+  showDebug(10, "m_info.qwFreeAllocs=%llu\n", m_info.qwFreeAllocs);
 
   // label == pascal string
   memset(m_header.szLabel, 0, 64);
-  memcpy(m_header.szLabel, ((char*)&sb.drVN)+1, min(((BYTE*)&sb.drVN)[0], 63));
-  localDebug("label=[%s]\n", m_header.szLabel);
+  memcpy(m_header.szLabel, ((char*)&sb.drVN)+1, my_min(((BYTE*)&sb.drVN)[0], 63));
+  showDebug(10, "label=[%s]\n", m_header.szLabel);
 
   // calculate sectors count
   m_header.qwBlocksCount = m_info.qwFirstAllocBlock // first reserved (2 boot blocks, 1 superblock, ...)
     + (m_info.dwBlocksPerAlloc * m_info.qwAllocCount) // allocation blocks
     + 1 // alternate superblock
     + 1; // last volume of sector
-  localDebug("m_header.qwBlocksCount = %llu\n", m_header.qwBlocksCount);
+  showDebug(10, "m_header.qwBlocksCount = %llu\n", m_header.qwBlocksCount);
    
   m_header.qwBlockSize = 512;
 
@@ -140,10 +142,10 @@ void CHfsPart::printfInformations()
   getStdInfos(szText, sizeof(szText), true);
   
   SNPRINTF(szFullText, i18n("%s" // standard infos
-			    "Allocation Group count:.......%llu\n"
-			    "Blocks per Allocation Group...%lu\n"
+			    "Allocation Group count:.......%"PRIu64"\n"
+			    "Blocks per Allocation Group...%u\n"
 			    "Allocation Group size:........%s\n"
-			    "First allocation block:.......%llu\n"),
+			    "First allocation block:.......%"PRIu64"\n"),
 	   szText, m_info.qwAllocCount, m_info.dwBlocksPerAlloc,
 	   formatSize(m_info.dwAllocSize,szTemp1), m_info.qwFirstAllocBlock);
     
@@ -166,7 +168,7 @@ void CHfsPart::readBitmap(COptions *options)
   
   // init bitmap
   const DWORD dwHighBit= 1<<31;
-  localDebug("m_header.qwBitmapSize=%llu\n",m_header.qwBitmapSize);
+  showDebug(10, "m_header.qwBitmapSize=%llu\n",m_header.qwBitmapSize);
   m_bitmap.init(m_header.qwBitmapSize+1024);
 
   // special sectors (begin and end of volume) are used
@@ -175,10 +177,10 @@ void CHfsPart::readBitmap(COptions *options)
 
   for (i=0; i < m_info.qwFirstAllocBlock; i++)
     {
-      localDebug("Block [%llu] is special\n", i);
+      showDebug(10, "Block [%llu] is special\n", i);
       m_bitmap.setBit(i, true);
     }
-  localDebug("Blocks [%llu] and [%llu] are special\n", qwLastAllocSector, qwLastAllocSector+1);
+  showDebug(10, "Blocks [%llu] and [%llu] are special\n", qwLastAllocSector, qwLastAllocSector+1);
   m_bitmap.setBit(qwLastAllocSector, true); // alternate superblock
   m_bitmap.setBit(qwLastAllocSector+1LL, true); // last volume of sector
 
@@ -190,7 +192,7 @@ void CHfsPart::readBitmap(COptions *options)
   nRes = readData(cTempData, (QWORD)(3*512), m_header.qwBitmapSize+512);
   if (nRes == -1)
     {
-      localDebug("ERROR 5\n");
+      showDebug(10, "ERROR 5\n");
       g_interface -> ErrorReadingSuperblock(errno);
       THROW(ERR_READING, (DWORD)0, errno);
     }
@@ -212,7 +214,7 @@ void CHfsPart::readBitmap(COptions *options)
 		  if (qwCurSector < qwLastAllocSector)
 		    {
 		      m_bitmap.setBit(qwCurSector, true);
-		      localDebug("used -> %llu\n", qwCurSector);
+		      showDebug(10, "used -> %llu\n", qwCurSector);
 		    }
 		}
 	    }
@@ -223,7 +225,7 @@ void CHfsPart::readBitmap(COptions *options)
 		  if (qwCurSector < qwLastAllocSector)
 		    {
 		      m_bitmap.setBit(qwCurSector, false);
-		      localDebug("free -> %llu\n", qwCurSector);
+		      showDebug(10, "free -> %llu\n", qwCurSector);
 
 		    }		
 		}
