@@ -5,7 +5,7 @@
     copyright            : (C) 2000 by Franois Dupoux
     email                : fdupoux@partimage.org
  ***************************************************************************/
-// $Revision: 1.25 $
+// $Revision: 1.1.1.1 $
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -29,6 +29,8 @@
 #include <stdlib.h>
 #include <errno.h>
 
+#define __STDC_FORMAT_MACROS
+#include <inttypes.h>
 // =======================================================
 void CRestoreMbrWindow::addHardDisk(char *szText, DWORD dwNumber)
 {
@@ -81,12 +83,12 @@ int CRestoreMbrWindow::create()
 }
 
 // =======================================================
-void CRestoreMbrWindow::getValues(DWORD *dwCurrentMbrNb, DWORD *dwOriginalMbrNb, int *nRestoreMode)
+void CRestoreMbrWindow::getValues(uintptr_t *dwCurrentMbrNb, uintptr_t *dwOriginalMbrNb, int *nRestoreMode)
 {
   BEGIN;
 
-  *dwCurrentMbrNb = (DWORD) newtListboxGetCurrent(m_list1);
-  *dwOriginalMbrNb = (DWORD) newtListboxGetCurrent(m_list2);
+  *dwCurrentMbrNb = (uintptr_t) newtListboxGetCurrent(m_list1);
+  *dwOriginalMbrNb = (uintptr_t) newtListboxGetCurrent(m_list2);
 
   if (newtRadioGetCurrent(m_radioFull) == m_radioFull)
     *nRestoreMode = MBR_RESTORE_WHOLE;
@@ -124,6 +126,7 @@ char *skipPartitionsEntries(char *cPtr)
 char *processHardDrive(char *cPtr, newtComponent editPartition)
 {
   char *cOldPtr;
+  char *FullyBatchMode = "";
   int nMajor, nMinor, nBlocks;
   int nPartNum;
   char szDevice[128];
@@ -152,7 +155,7 @@ char *processHardDrive(char *cPtr, newtComponent editPartition)
 	  memcpy(cFormat, szDevice, strlen(szDevice)); // Device
 	  
 	  SNPRINTF(szFullDevice, "/dev/%s", szDevice);
-	  checkInodeForDevice(szFullDevice);
+	  checkInodeForDevice(szFullDevice, FullyBatchMode);
 	  
 	  if (nBlocks > 1) // a standard device
 	    {
@@ -192,6 +195,7 @@ int fillPartitionList(newtComponent editPartition)
   char cFormat[1024];
   char szTemp[1024];
   char *cPtr;
+  char *FullyBatchMode = "";
   int nLines;
   unsigned int nSize;
   QWORD qwSize;
@@ -253,7 +257,7 @@ int fillPartitionList(newtComponent editPartition)
       
       // detect file system of the hard disk
       SNPRINTF(szFullDevice, "/dev/%s", szDevice);
-      checkInodeForDevice(szFullDevice);
+      checkInodeForDevice(szFullDevice, FullyBatchMode);
       nRes = detectFileSystem(szFullDevice, szTemp);
 
       showDebug(9, "device %s\n", szDevice);     
@@ -337,7 +341,7 @@ int CSaveOptWindow::create(char *szImageFile, COptions options)
   m_labelSplit = newtLabel(1, 12, i18n("Image split mode"));
   m_radioSplitAuto = newtRadiobutton(1, 13, i18n("Automatic split (when no space left)"), !options.qwSplitSize, NULL);
   m_radioSplitSize = newtRadiobutton(1, 14, i18n("Into files whose size is:............"), !!options.qwSplitSize, m_radioSplitAuto);
-  SNPRINTF(szTemp, "%llu", (!!options.qwSplitSize) ? (options.qwSplitSize/1024/1024) : 2048);
+  SNPRINTF(szTemp, "%"PRIu64"", (!!options.qwSplitSize) ? (options.qwSplitSize/1024/1024) : 2048);
   m_editSplitSize = newtEntry(43, 14, szTemp, 8, NULL, 0);
   m_labelSplitSizeKB = newtLabel(52, 14, i18n("MiB"));
   m_checkSplitWait = newtCheckbox(1, 15, i18n("Wait after each volume change"), (!!options.bSplitWait ? 'X' : ' '), " X", NULL);
@@ -458,7 +462,7 @@ int CSavingWindow::create(const char *szDevice, const char *szImageFile, const c
   SNPRINTF(szTemp, i18n("Partition to save:...........%s"), szDevice);
   m_labelPartition = newtLabel(1, 0, szTemp);
   
-  SNPRINTF(szTemp, i18n("Size of the Partition:.......%s = %llu bytes"), formatSize(qwPartSize, szTemp2), qwPartSize);
+  SNPRINTF(szTemp, i18n("Size of the Partition:.......%s = %"PRIu64" bytes"), formatSize(qwPartSize, szTemp2), qwPartSize);
   m_labelPartitionSize = newtLabel(1, 1, szTemp);
   
   SNPRINTF(szTemp, i18n("Image file to create.........%s"), szImageFile);
@@ -508,7 +512,7 @@ int CSavingWindow::create(const char *szDevice, const char *szImageFile, const c
 }
 
 // =======================================================
-void CSavingWindow::showStats(const time_t timeStart, QWORD qwBlockSize, QWORD qwBlocksDone, QWORD qwBlocksTotal)
+void CSavingWindow::showStats(const time_t timeStart, QWORD qwBlockSize, QWORD qwBlocksDone, QWORD qwBlocksTotal, char *szFullyBatchMode)
 {
   BEGIN;
 
@@ -549,6 +553,18 @@ void CSavingWindow::showStats(const time_t timeStart, QWORD qwBlockSize, QWORD q
       
       SNPRINTF(szTemp, i18n("Data copied:.................%s / %s"), formatSize(qwDone, szTemp2), formatSize(qwTotal, szTemp3));
       newtLabelSetText(m_labelStatsSpace, szTemp);
+
+      //option  -B gui=no show stats
+      if ((szFullyBatchMode) && (strlen(szFullyBatchMode)>0))
+      {
+	        fprintf(stderr,"\r\t\t\t\b\b");
+	        SNPRINTF(szTemp, i18n("T:%-s/%-s"), formatTimeNG((DWORD)timeElapsed, szTemp2), formatTimeNG((DWORD)timeRemaining, szTemp3));
+	        fprintf(stderr,"%-s  ",szTemp);
+	        SNPRINTF(szTemp, i18n("R:%s/min"), formatSizeNG(qwBytesPerMin, szTemp2));
+	        fprintf(stderr,"%-s  ",szTemp);
+	        SNPRINTF(szTemp, "P:%3d%%", (int)qwPercent);
+	        fprintf(stderr,"%-s",szTemp);
+      }
     }
 
   newtRefresh();
@@ -572,13 +588,19 @@ void CSavingWindow::destroyForm()
 }
 
 // =======================================================
-void CSavingWindow::showImageFileInfo(char *szImageFile, QWORD qwFreeSpace, QWORD qwImageSize)
+void CSavingWindow::showImageFileInfo(char *szImageFile, QWORD qwFreeSpace, QWORD qwImageSize, char *szFullyBatchMode)
 {
   BEGIN;
 
   char szTemp[2048];
   char szTemp2[2048];
-  
+  char szTemp3[2048];
+  char f1[9];
+  char f2[5];
+  char d[]="./";
+
+  if (strncmp(szImageFile,d,2)==0)
+      szImageFile=szImageFile+strlen(d);
   SNPRINTF(szTemp, i18n("Current image file:..........%s"), szImageFile);
   newtLabelSetText(m_labelImageFile, szTemp);
 
@@ -588,9 +610,35 @@ void CSavingWindow::showImageFileInfo(char *szImageFile, QWORD qwFreeSpace, QWOR
       newtLabelSetText(m_labelImageFileSize, szTemp);
     }
   
-  SNPRINTF (szTemp, i18n("Available space for image:...%s = %llu bytes"), formatSize(qwFreeSpace, szTemp2), qwFreeSpace);
+  SNPRINTF (szTemp, i18n("Available space for image:...%s = %"PRIu64" bytes"), formatSize(qwFreeSpace, szTemp2), qwFreeSpace);
   newtLabelSetText(m_labelFreeSpace, szTemp);
 
+  //option -B gui=no
+  if ((szFullyBatchMode) && (strlen(szFullyBatchMode)>0))
+  {
+
+       if(strrchr(szImageFile,'/'))
+          szImageFile = strrchr(szImageFile,'/')+1;
+
+    if (strlen(szImageFile) > 12)
+    {
+
+      snprintf(f1, 9, i18n("%-s"), szImageFile);
+      snprintf(f2, 5, i18n("%-s"), strrchr(szImageFile,'.'));
+      if (strrchr(szImageFile,'.') != 0)
+      {
+          SNPRINTF(szTemp,"%-s~%-s",f1,f2);
+      }else{
+          snprintf(szTemp, 12, i18n("%-s"), szImageFile);
+      }
+    }else{
+      snprintf(szTemp, 12, i18n("%-s"), szImageFile);
+    }
+
+    SNPRINTF(szTemp3, i18n("%-12s S:%-s "), szTemp, formatSizeNG(qwImageSize, szTemp2));
+    fprintf(stderr,"\r%-s",szTemp3);
+  }  
+
   RETURN;
 }
 
@@ -650,8 +698,27 @@ int CRestoreOptWindow::getValues(COptions *options)
   RETURN_int(0);
 }
 
+static char *asctime_portable (const struct portable_tm *__tp)
+{
+struct tm tms;
+
+	tms.tm_sec=__tp->tm_sec;
+	tms.tm_min=__tp->tm_min;
+	tms.tm_hour=__tp->tm_hour;
+	tms.tm_mday=__tp->tm_mday;
+	tms.tm_mon=__tp->tm_mon;
+	tms.tm_year=__tp->tm_year;
+	tms.tm_wday=__tp->tm_wday;
+	tms.tm_yday=__tp->tm_yday;
+	tms.tm_isdst=__tp->tm_isdst;
+	tms.tm_gmtoff=__tp->tm_gmtoff;
+	tms.tm_zone="UTC";
+
+	return asctime (&tms);
+}
+
 // =======================================================
-int CRestoringWindow::create(char *szDevice, char *szImageFile, QWORD qwCurPartSize, DWORD dwCompressionMode, char *szOriginalDevice, char *szFileSystem, tm dateCreate, QWORD qwOrigPartSize, COptions * options)
+int CRestoringWindow::create(char *szDevice, char *szImageFile, QWORD qwCurPartSize, DWORD dwCompressionMode, char *szOriginalDevice, char *szFileSystem, struct portable_tm dateCreate, QWORD qwOrigPartSize, COptions * options)
 {
   BEGIN;
   
@@ -667,7 +734,7 @@ int CRestoringWindow::create(char *szDevice, char *szImageFile, QWORD qwCurPartS
   SNPRINTF(szTemp, i18n("Partition to restore:.............%s"), szDevice);
   m_labelPartition = newtLabel(1, 0, szTemp);
   
-  SNPRINTF(szTemp, i18n("Size of partition to restore:.....%s = %llu bytes"), formatSize(qwCurPartSize, szTemp2), qwCurPartSize);
+  SNPRINTF(szTemp, i18n("Size of partition to restore:.....%s = %"PRIu64" bytes"), formatSize(qwCurPartSize, szTemp2), qwCurPartSize);
   m_labelPartitionSize = newtLabel(1, 1, szTemp);
   
   SNPRINTF(szTemp, i18n("Image file to use.................%s"), szImageFile);
@@ -681,10 +748,10 @@ int CRestoringWindow::create(char *szDevice, char *szImageFile, QWORD qwCurPartS
   SNPRINTF(szTemp, i18n("Partition was on device:..........%s\n"), szOriginalDevice);
   m_labelOldDevice = newtLabel(1, 5, szTemp);
 
-  SNPRINTF(szTemp, i18n("Image created on:.................%s\n"), asctime(&dateCreate));
+  SNPRINTF(szTemp, i18n("Image created on:.................%s\n"), asctime_portable(&dateCreate));
   m_labelDate = newtLabel(1, 6, szTemp);
 
-  SNPRINTF(szTemp, i18n("Size of the original partition:...%s = %llu bytes"), formatSize(qwOrigPartSize, szTemp2), qwOrigPartSize);
+  SNPRINTF(szTemp, i18n("Size of the original partition:...%s = %"PRIu64" bytes"), formatSize(qwOrigPartSize, szTemp2), qwOrigPartSize);
   m_labelOriginalPartitionSize = newtLabel(1, 7, szTemp);
 
   // stats
@@ -709,7 +776,7 @@ int CRestoringWindow::create(char *szDevice, char *szImageFile, QWORD qwCurPartS
 }
 
 // =======================================================
-void CRestoringWindow::showStats(const time_t timeStart, QWORD qwBlockSize, QWORD qwBlocksDone, QWORD qwBlocksUsed, QWORD qwBlocksTotal, bool bEraseWithNull)
+void CRestoringWindow::showStats(const time_t timeStart, QWORD qwBlockSize, QWORD qwBlocksDone, QWORD qwBlocksUsed, QWORD qwBlocksTotal, bool bEraseWithNull, char *szFullyBatchMode)
 {
   BEGIN;
 
@@ -764,6 +831,17 @@ void CRestoringWindow::showStats(const time_t timeStart, QWORD qwBlockSize, QWOR
       
       SNPRINTF(szTemp, i18n("Data copied:......................%s / %s"), formatSize(qwDone, szTemp2), formatSize(qwTotal, szTemp3));
       newtLabelSetText(m_labelStatsSpace, szTemp);
+      //option  -B gui=no show stats
+      if ((szFullyBatchMode) && (strlen(szFullyBatchMode)>0))
+      {
+        fprintf(stderr,"\r\t\t\t\b\b");
+        SNPRINTF(szTemp, i18n("T:%-s/%-s"), formatTimeNG((DWORD)timeElapsed, szTemp2), formatTimeNG((DWORD)timeRemaining, szTemp3));
+        fprintf(stderr,"%-s  ",szTemp);
+        SNPRINTF(szTemp, i18n("R:%s/min"), formatSizeNG(qwBytesPerMin, szTemp2));
+        fprintf(stderr,"%-s  ",szTemp);
+        SNPRINTF(szTemp, "P:%3d%%", (int)qwPercent);
+        fprintf(stderr,"%-s",szTemp);
+      }
     }
 
   newtRefresh();
@@ -787,11 +865,19 @@ void CRestoringWindow::destroyForm()
 }
 
 // =======================================================
-void CRestoringWindow::showImageFileInfo(char *szImageFile, int nCompressionMode)
+void CRestoringWindow::showImageFileInfo(char *szImageFile, int nCompressionMode, char *szFullyBatchMode)
 {
   BEGIN;
   
   char szTemp[2048];
+  char szTemp2[2048];
+  char szTemp3[2048];
+  char f1[9];
+  char f2[5];
+  char d[]="./";
+
+  if (strncmp(szImageFile,d,2)==0)
+      szImageFile=szImageFile+strlen(d);
 
   SNPRINTF(szTemp, i18n("Current image file:...............%s"), szImageFile);	
   newtLabelSetText(m_labelImageFile, szTemp);
@@ -802,23 +888,54 @@ void CRestoringWindow::showImageFileInfo(char *szImageFile, int nCompressionMode
 	{
 	case COMPRESS_NONE:
 	  SNPRINTF(szTemp, i18n("Compression level:................None\n"));
+          SNPRINTF(szTemp2, i18n("None"));
 	  break;
 	case COMPRESS_GZIP:
 	  SNPRINTF(szTemp, i18n("Compression level:................gzip"));
+          SNPRINTF(szTemp2, i18n("gzip"));
 	  break;
 	case COMPRESS_BZIP2:
 	  SNPRINTF(szTemp, i18n("Compression level:................bzip2"));
+          SNPRINTF(szTemp2, i18n("bzip2"));
 	  break;
 	case COMPRESS_LZO:
 	  SNPRINTF(szTemp, i18n("Compression level:................lzo"));
+          SNPRINTF(szTemp2, i18n("lzo"));
 	  break;
 	default:
-	  memset(szTemp, 0, sizeof(szTemp));
-	}
-
-      newtLabelSetText(m_labelCompression, szTemp);
+          memset(szTemp2, 0, sizeof(szTemp2));
+        SNPRINTF(szTemp3, i18n("Compression level:................%s"),szTemp2);
+        newtLabelSetText(m_labelCompression, szTemp3);
+       }
     }
 
+  //option -B gui=no
+  if ((szFullyBatchMode) && (strlen(szFullyBatchMode)>0))
+  {
+       if(strrchr(szImageFile,'/'))
+          szImageFile = strrchr(szImageFile,'/')+1;
+
+    if (strlen(szImageFile) > 12)
+    {
+
+      snprintf(f2, 5, i18n("%-s"), strrchr(szImageFile,'.'));
+      snprintf(f1, 9, i18n("%-s"), szImageFile);
+         showDebug(3,"f1=%s, f2=%s",f1,f2);
+      if (strrchr(szImageFile,'.') != 0)
+      {
+          SNPRINTF(szTemp,"%-s~%-s",f1,f2);
+      }else{
+          snprintf(szTemp, 12, i18n("%-s"), szImageFile);
+      }
+    }else{
+      snprintf(szTemp, 12, i18n("%-s"), szImageFile);
+    }
+
+    SNPRINTF(szTemp3, i18n("%-12s %-s "), szTemp, szTemp2);
+    fprintf(stderr,"\r%-s",szTemp3);
+  }
+
+
   RETURN;
 }
 
