@@ -56,7 +56,7 @@ class CRestoreMbrWindow: public COptionsWindow
   void addMbr(char *szText, DWORD dwNumber);
   //int runForm();
   //void destroyForm();
-  void getValues(DWORD *dwCurrentMbrNb, DWORD *dwOriginalMbrNb, int *nRestoreMode);
+  void getValues(uintptr_t *dwCurrentMbrNb, uintptr_t *dwOriginalMbrNb, int *nRestoreMode);
 	
  private:
   //newtComponent m_formMain;
@@ -109,9 +109,8 @@ class CSavingWindow
   int create(const char *szDevice, const char *szImageFile, const char *szFilesystem, QWORD qwPartSize, COptions options);
   int runForm();
   void destroyForm();
-  void showImageFileInfo(char *szImageFile, QWORD qwFreeSpace, QWORD qwImageSize);
-  void showStats(const time_t timeStart, QWORD qwBlockSize, QWORD qwBlocksDone, QWORD qwBlocksTotal);
-  
+  void showImageFileInfo(char *szImageFile, QWORD qwFreeSpace, QWORD qwImageSize, char *szFullyBatchMode);
+  void showStats(const time_t timeStart, QWORD qwBlockSize, QWORD qwBlocksDone, QWORD qwBlocksTotal, char *szFullyBatchMode);
  private:
   newtComponent m_formMain;
   newtComponent m_labelPartition, m_labelPartitionSize, m_labelImageFile, m_labelImageFileSize, m_labelFS;
@@ -125,11 +124,11 @@ class CSavingWindow
 class CRestoringWindow
 {
  public:
-  int create(char *szDevice, char *szImageFile, QWORD qwCurPartSize, DWORD dwCompressionMode, char *szOriginalDevice, char *szFileSystem, tm dateCreate, QWORD qwOrigPartSize, COptions * options);
+  int create(char *szDevice, char *szImageFile, QWORD qwCurPartSize, DWORD dwCompressionMode, char *szOriginalDevice, char *szFileSystem, struct portable_tm dateCreate, QWORD qwOrigPartSize, COptions * options);
   int runForm();
   void destroyForm();
-  void showImageFileInfo(char *szImageFile, int nCompressionMode);
-  void showStats(const time_t timeStart, QWORD qwBlockSize, QWORD qwBlocksDone, QWORD qwBlocksUsed, QWORD qwBlocksTotal, bool bEraseWithNull);
+  void showImageFileInfo(char *szImageFile, int nCompressionMode, char *szFullyBatchMode);
+  void showStats(const time_t timeStart, QWORD qwBlockSize, QWORD qwBlocksDone, QWORD qwBlocksUsed, QWORD qwBlocksTotal, bool bEraseWithNull, char *szFullyBatchMode); 
 	
 private:
   newtComponent m_formMain;
