@@ -61,31 +61,38 @@ CImage::CImage(COptions * options)
   else
     {
 #ifdef MUST_LOGIN
-      if (strlen(options -> szUserName) && strlen(options -> szPassWord))
+      if (options->bMustLogin)
         {
-          strncpy(login, options->szUserName, 2048);
-          strncpy(passwd, options->szPassWord, 2048);
-          *(login+2047) = '\0';
-          *(passwd+2047) = '\0';
-        }
-      else 
-        {
-// we get login/pass from user
-          int nRes;
-          nRes = g_interface -> askLogin(login, passwd, 2048);
-          if (nRes)
+          if (strlen(options -> szUserName) && strlen(options -> szPassWord))
             {
-              free(login);
-              free(passwd);
-              THROW( ERR_CANCELED);
+              strncpy(login, options->szUserName, 2048);
+              strncpy(passwd, options->szPassWord, 2048);
+              *(login+2047) = '\0';
+              *(passwd+2047) = '\0';
             }
-        }	
-#else
+          else 
+            {
+    // we get login/pass from user
+              int nRes;
+              nRes = g_interface -> askLogin(login, passwd, 2048);
+              if (nRes)
+                {
+                  free(login);
+                  free(passwd);
+                  THROW( ERR_CANCELED);
+                }
+            }	
+        }
+      else
+        {
+#endif
 // fake login/passwd
       strcpy(login, "nologin");
       strcpy(passwd, "nopass");
+#ifdef MUST_LOGIN
+        }
 #endif
-		
+
       m_cid = new CImageNet(options, options->bUseSSL);
       try { m_cid -> Connect(options, login, passwd, options->szServerName,
          options->dwServerPort); }
