@@ -34,6 +34,8 @@ public:
   CInterface(bool bBatchMode) {m_bBatchMode = bBatchMode;} 
   virtual ~CInterface() {} 
 
+  bool getBatchMode() { return m_bBatchMode; }
+
   // defined in herited classes
   virtual void msgBoxOk(char *szTitle, char *szText, ...)=0;
   virtual void msgBoxCancel(char *szTitle, char *szText, ...)=0;
@@ -93,16 +95,16 @@ public:
 /**/  void ErrorInvalidFS(char * szFs);
 /**/  void ErrorLocking(char * szFilename, signed int err);
 
-  /*virtual void StatusLine(char * str)=0;
-  virtual int guiInitMainWindow(char * szDevice, char * szImageFile, char *
-     szNetworkIP, DWORD * dwServerPort, bool * bSsl)=0;
-  virtual void askDescription(char * szDescription, DWORD dwMaxLen)=0;
-  virtual int askText(char * szMessage, char * szTitle, char * szDestText)=0;
-  virtual int askText(char * szMessage, char * szTitle, char * szDestText,
-     WORD size)=0;
+  virtual void StatusLine(char * str)=0;
   virtual int askLogin(char * szLogin, char * szPasswd, WORD size)=0;
   virtual WORD askNewPath(char * szOriginalFilename, DWORD dwVolume,
      char * szPath, char *szNewPath, WORD size)=0;
+  virtual int askText(char * szMessage, char * szTitle, char * szDestText,
+     WORD size)=0;
+  virtual void askDescription(char * szDescription, DWORD dwMaxLen)=0;
+  virtual int guiInitMainWindow(char * szDevice, char * szImageFile, char *
+     szNetworkIP, DWORD * dwServerPort, bool * bSsl)=0;
+  /*virtual int askText(char * szMessage, char * szTitle, char * szDestText)=0;
   virtual void showAboutDialog()=0;
   virtual WORD windowRoot()=0;
   virtual WORD WaitKeyPressed(char * szOld, char * szNewPath,
@@ -113,9 +115,12 @@ public:
 //  WORD Error(CExceptions * excep, char * szFilename);
 
   WORD ErrorLogAsRoot();
+  WORD ErrorBugBzip2();
   WORD WaitKeyPressed(char *szOld, char *szNewPath, char *szOriginalFilename, DWORD dwVolume);
   WORD askRestore(char *szDevice, char *szImageFilename);
   WORD askIgnoreFSError(char *szFsck);
+  WORD askIgnoreNoFschk(char *szFsck);
+  WORD askIgnoreDeniedFschk(char *szFsck);
   void WarnFS(char *szFileSys);
   void WarnFsBeta(char *szFileSys);
   void WarnSimulate();
