@@ -90,6 +90,7 @@ static struct option const long_options[] =
   {"compilinfo", no_argument, NULL, 'i'},
   {"nombr", no_argument, NULL, 'M'},
   {"allowmnt", no_argument, NULL, 'm'},
+  {"nologin", no_argument, NULL, 'L'},
   {"nossl", no_argument, NULL, 'n'},
   {"overwrite", no_argument, NULL, 'o'},
   {"password", required_argument, NULL, 'P'},
@@ -109,7 +110,7 @@ static struct option const long_options[] =
 
 static char finish_last_countfile_lock[]="/tmp/partimageXXXXXX.lock";
 static char finish_last_countfile[]="/tmp/partimageXXXXXX";
-static char optstring[]="z:oV:ecmdhf:s:p:bwg:vynSMa:iU:P:XB:";
+static char optstring[]="z:oV:ecmdhf:s:p:bwg:vyLnSMa:iU:P:XB:";
 FILE * g_fDebug; // debug file
 FILE * g_fLocalDebug; // debug file
 CInterface * g_interface;
@@ -171,6 +172,7 @@ int main(int argc, char *argv[])
   // initialize options with defaults values
   memset(&options, 0, sizeof(COptions));
   options.bUseSSL = OPTIONS_DEFAULT_SSL;
+  options.bMustLogin = OPTIONS_DEFAULT_LOGIN;
   options.bBackupMBR = OPTIONS_DEFAULT_BACKUP_MBR;
   options.bSimulateMode = OPTIONS_DEFAULT_SIMULATE_MODE;
   options.bOverwrite = OPTIONS_DEFAULT_OVERWRITE;
@@ -329,9 +331,14 @@ int main(int argc, char *argv[])
 	    return EXIT_SUCCESS;
 	    break;
 
+	  case 'L': // no login
+	    options.bMustLogin = false;
+	    break;
+
 	  case 'n': // no ssl
 	    options.bUseSSL = false;
 	    break;
+
 	  case 'S': // simulate
 	    options.bSimulateMode = true;
 	    break;
@@ -527,6 +534,10 @@ int main(int argc, char *argv[])
 	nChoice = OPERATION_SAVE_ALL;
       else if (strcmp(argv[optind], "rest_all")==0)
 	nChoice = OPERATION_REST_ALL;
+      else if (strcmp(argv[optind], "save_file")==0)
+	nChoice = OPERATION_SAVE_FILE;
+      else if (strcmp(argv[optind], "rest_file")==0)
+	nChoice = OPERATION_REST_FILE;
 
       strncpy(nChoice == OPERATION_REST_ALL || nChoice == OPERATION_SAVE_ALL ? szImageDir : szImageFile, argv[optind+1], MAXPATHLEN);      
     }
@@ -649,6 +660,34 @@ int main(int argc, char *argv[])
 	  nRes = -1;
 	}
       break;
+
+    case OPERATION_SAVE_FILE:
+      showDebug(1, "action=SAVE_FILE\n");
+      try { save_file(szImageFile, &options); }
+      catch (CExceptions *excep)
+	{
+          showDebug(1, "save_file caught exception: %d\n", excep->GetExcept());
+
+	  if (options.bBatchMode) ensure_interface_is_non_interactive();	      
+	  g_interface -> Error(excep, szImageFile, "");
+
+	  nRes = -1;
+	}
+      break;
+
+    case OPERATION_REST_FILE:
+      showDebug(1, "action=REST_FILE\n");
+      try { rest_file(szImageFile, &options); }
+      catch (CExceptions *excep)
+	{
+          showDebug(1, "rest_file caught exception: %d\n", excep->GetExcept());
+
+	  if (options.bBatchMode) ensure_interface_is_non_interactive();	      
+	  g_interface -> Error(excep, szImageFile, "");
+
+	  nRes = -1;
+	}
+      break;
       
     case OPERATION_IMGINFO:
       showDebug(1, "action=IMGINFO\n");
@@ -837,15 +876,16 @@ int main(int argc, char *argv[])
 	  {
 	    if ((fd_lock = mkstemp(finish_last_countfile_lock)) == -1)
 	      {
-		delete g_interface;
-		fprintf(stderr, i18n("Error: Cannot create lock for countfile"));
-		return EXIT_FAILURE;
-	      }
+			--nRetries;
+			sleep(2);
+			continue;
+		  }
 	    fLockFile = fdopen(fd_lock, "r");
 	    if (fLockFile == NULL)
  	      {
-                 --nRetries;
- 		sleep(2);
+			close(fd_lock);
+			unlink(finish_last_countfile_lock);
+			sleep(2);
  	      }
 	  } while (fLockFile == NULL && nRetries);
  	  if (!nRetries)
@@ -856,6 +896,10 @@ int main(int argc, char *argv[])
  	    }
 	  if ((fd_countfile = mkstemp(finish_last_countfile)) == -1)
 	    {
+			fclose(fLockFile);
+			close(fd_lock);
+			unlink(finish_last_countfile_lock);
+
 	      delete g_interface;
 	      fprintf(stderr, i18n("Error: Cannot create countfile"));
 	      return EXIT_FAILURE;
@@ -863,6 +907,12 @@ int main(int argc, char *argv[])
           fCountFile = fdopen(fd_countfile, "r");
 	  if (fCountFile == NULL)
 	    {
+			fclose(fLockFile);
+			close(fd_lock);
+			close(fd_countfile);
+			unlink(finish_last_countfile_lock);
+			unlink(finish_last_countfile);
+
     	      delete g_interface; 
 	      fprintf(stderr, i18n("Error: Cannot count remaining partimages"));
 	      return EXIT_SUCCESS;
@@ -972,6 +1022,7 @@ void usage()
 	      "* -sX, --server=X      give partimaged server's ip address\n"
 	      "* -pX, --port=X        give partimaged server's listening port\n"
 	      "* -g,  --debug=X       set the debug level to X (default: 1):\n"
+	      "* -L,  --nologin       disable login in network mode\n"
 	      "* -n,  --nossl         disable SSL in network mode\n"
 	      "* -S,  --simulate      simulation of restoration mode\n"
 	      "* -aX, --automnt=X     automatic mount with X options. Read the doc for more details\n"
