@@ -47,6 +47,10 @@ int isDevfsEnabled();
 void savePartition(char *szDevice, char *szImageName, /*char *szFilesystem, */COptions *options);
 void restorePartition(char *szDevice, char *szImageName, COptions *options);
 void restoreMbr(char *szImageFile, COptions *options);
+void save_all(char *szImageDir, COptions *options);
+void rest_all(char *szImageDir, COptions *options);
+void save_file(char *szImageFile, COptions *options);
+void rest_file(char *szImageFile, COptions *options);
 
 // =======================================================
 void closeFilesSave(bool on_error, COptions options, CImage *image, FILE *fDeviceFile);
@@ -212,7 +216,7 @@ int detectFileSystem(const char *szDevice, char *szFileSys);
  *  @param szDevice The device partition to chek for inode (ex: "/dev/hda1")
  *  @return @p 0 if success, @p -1 if error
 */
-int checkInodeForDevice(char *szDevice);
+int checkInodeForDevice(char *szDevice,  char *szFullyBatchMode);
 
 /** It allows to make a fseek (SEEK_CUR mode only) in a file with offsets greaters than 2 GB.
     For example, you can seek 8 GB with this function.
@@ -230,7 +234,7 @@ int bigFseek(FILE *fStream, QWORD qwOffset); // SEEK_SET forced
  *  @param bFailIfMounted: true if the function must return an error if the partition is mounted
  *  @return @p -1 if error or @p 0 if success
 */
-int systemChecks(char *szDevice, bool bFailIfMounted);
+int systemChecks(char *szDevice, bool bFailIfMounted, char *szFullyBatchMode);
 
 /** This function receives data of the /proc/partitions files, pases it and
  *  returns the informations it contains (major, minor, blocks, partnum, device).
@@ -253,7 +257,8 @@ char *decodePartitionEntry(char *cPtr, int *nMajor, int *nMinor, int *nBlocks, i
 int checkOptions(COptions options, char *szDevice, char *szImageFile);
 
 int CXfsPartdetect(BYTE *cBootSect, char *szFileSystem);
-int CReiserPartdetect(BYTE *cBootSect, char *szFileSystem);
+int CReiser3Partdetect(BYTE *cBootSect, char *szFileSystem);
+int CReiser4Partdetect(BYTE *cBootSect, char *szFileSystem);
 int CExt2Partdetect(BYTE *cBootSect, char *szFileSystem);
 int CAfsPartdetect(BYTE *cBootSect, char *szFileSystem);
 int CJfsPartdetect(BYTE *cBootSect, char *szFileSystem);
