@@ -23,6 +23,8 @@
 #include <stdio.h>
 #include <stdint.h>
 #include <time.h>
+#define __STDC_FORMAT_MACROS
+#include <inttypes.h>
 
 #ifdef HAVE_CONFIG_H
   #include <config.h>
@@ -97,6 +99,8 @@ extern bool g_bSigKill;
 #define OPERATION_EXIT       5
 #define OPERATION_SAVE_ALL   6
 #define OPERATION_REST_ALL   7
+#define OPERATION_SAVE_FILE  8
+#define OPERATION_REST_FILE  9
 
 // returned by CExceptionsGUI::windowError 
 // user canceled the job
@@ -190,6 +194,7 @@ extern bool g_bSigKill;
 #define OPTIONS_DEFAULT_SPLIT_WAIT            false
 #define OPTIONS_DEFAULT_RUN_SHELL             false
 #define OPTIONS_DEFAULT_SYNC                  true
+#define OPTIONS_DEFAULT_LOGIN                 true
 #define OPTIONS_DEFAULT_SSL                   true
 #define OPTIONS_DEFAULT_BACKUP_MBR            true
 #define OPTIONS_DEFAULT_SIMULATE_MODE         false
