@@ -27,7 +27,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <iostream.h>
+#include <iostream>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <signal.h>
@@ -58,6 +58,7 @@ bool g_bBeDaemon;
 CNetServer * g_Server;
 CPartimagedInterface * g_Window;
 bool g_bMustLogin;
+bool g_bUseSSL;
 
 extern char * optarg;
 extern int optind;
@@ -76,11 +77,12 @@ static struct option const long_options[] =
   {"chroot", required_argument, NULL, 'r'},
   {"debug", required_argument, NULL, 'g'},
   {"nologin", no_argument, NULL, 'L'},
+  {"nossl", no_argument, NULL, 'n'},
   {NULL, 0, NULL, 0}
 };
 #endif //HAVE_GETOPT_H
 
-static char optstring[]="ip:hvDd:r:g:L"; 
+static char optstring[]="ip:hvDd:r:g:Ln"; 
 
 bool g_bSigKill = false;
 bool g_bSigInt = false;
@@ -135,7 +137,8 @@ void Usage()
 	       "* -i,  --compilinfo      show compilation options used\n"
 	       "* -r dir, --chroot dir   use chroot to improve security\n"
 	       "* -g, --debug=X          set the debug level to X (default: 1)\n"
-               "* -L, --nologin          disable login from clients\n"),
+               "* -L, --nologin          disable login from clients\n"
+               "* -n, --nossl            disable SSL\n"),
 	  PACKAGE_VERSION, SERVER_LISTEN_PORT);
   printf ("======================================================="
 	  "========================\n");
@@ -211,6 +214,7 @@ int main(int argc, char *argv[])
   g_nDebugThreadMain = getpid();
   g_bBeDaemon = false;
   g_bMustLogin = true;
+  g_bUseSSL = true;
 
   pthread_t threads[MAX_CLIENTS];
 
@@ -263,6 +267,12 @@ int main(int argc, char *argv[])
 
           case 'L':  // no login
             g_bMustLogin = false;
+            break;
+
+          case 'n':  // no SSL
+            g_bUseSSL = false;
+            break;
+
           default:
             break;
         }
@@ -313,9 +323,12 @@ int main(int argc, char *argv[])
     }
 #endif
 #ifdef HAVE_SSL
-  if ( CheckAccessFile(KEYF) || CheckAccessFile(CERTF) )
-    {
-      exit(1);   
+  if (g_bUseSSL)
+    { 
+      if ( CheckAccessFile(KEYF) || CheckAccessFile(CERTF) )
+        {
+          exit(1);   
+        }
     }
 #endif    
 
