@@ -524,8 +524,9 @@ void CImageDisk::openWriting() // [Main-Thread]
   if (m_bIsOpened == true)
     THROW(ERR_OPENED);
   
-  SNPRINTF(szShortName, "pi%.8lx", (DWORD)generateIdentificator());
+  SNPRINTF(szShortName, "pi%.8x", (DWORD)generateIdentificator());
   extractFilepathFromFullPath(m_szImageFilename, szPathDir); // filepath without filename
+  if (access(szPathDir, R_OK) == -1) mkdir(szPathDir, 0755);
   snprintf(m_szSpaceFilename, MAXPATHLEN, "%s/%8s.tmp", szPathDir, szShortName);
   showDebug(1, "TEMP=[%s]\n", m_szSpaceFilename);
 
