@@ -30,11 +30,12 @@ size_t CNet::nSend(CIdefRemote remote, const void * buf, size_t len)
   showDebug(3, "begin # %ld for %d bytes \n", nb, len);
 
 #ifdef HAVE_SSL
+  showDebug(3, "send avec ssl\n");
   if (remote.Ssl)
     res = SSL_write(remote.Ssl, (char *) buf, len);
   else
 #endif
-    res = send(remote.Sock, buf, len, 0);
+    res = send(remote.Sock, buf, len, MSG_NOSIGNAL); 
 
   if (res != len)
     showDebug(1, "end: %s\n", strerror(errno));
@@ -83,7 +84,6 @@ size_t CNet::nRecvMsg(CIdefRemote remote, CMessages * msg)
 
   msg->fromString((char *) buf);
   free(buf);
-  showDebug(3, "end (*) msg=%d\n", msg->getCmd());
   return res;
 }
 
@@ -91,7 +91,6 @@ size_t CNet::nRecvMsg(CIdefRemote remote, CMessages * msg)
 size_t CNet::nSendMsg(CIdefRemote remote, CMessages * msg)
 {
   size_t len;
-  showDebug(3, "begin (*) msg= %d\n", msg->getCmd());
 
   len = nSend(remote, msg->toString(), MESSAGE_LEN);
 
@@ -108,7 +107,7 @@ char * CNet::Banner(bool bUseSSL, bool bMustLogin)
   char * szBanner = (char *) malloc (BANNER_SIZE+1);
   memset(szBanner, ' ', BANNER_SIZE);
   *(szBanner+BANNER_SIZE) = '\0';
-  strcpy(szBanner, VERSION);
+  strcpy(szBanner, PACKAGE_VERSION);
 #ifdef HAVE_SSL
   if (bUseSSL)
     { strcat(szBanner, " SSL"); }
